%define oname   dose3
%global giturl  https://gitlab.com/irill/dose3
%global libname %(echo %{name} | sed -e 's/^ocaml-//')

Name:           ocaml-dose3
Version:        7.0.0
Release:        %mkrel 5
Summary:        Framework for managing distribution packages and dependencies
Group:          Development/OCaml
License:        LGPL-3.0-or-later WITH OCaml-LGPL-linking-exception
URL:            http://www.mancoosi.org/software/
VCS:            git:%{giturl}.git
Source:         %{giturl}/-/archive/%{version}/dose3-%{version}.tar.gz

# Use oUnit2 instead of oUnit
Patch:          0001-Use-ounit2.patch
# We do not need stdlib-shims, which provides forward compatibility
Patch:          0002-Do-not-depend-on-stdlib-shims.patch
# Expose a dependency on the math library so RPM can see it
Patch:          0003-Depend-on-the-math-library.patch
# Changes for OCaml 5 compatibility
Patch:          0004-OCaml-5-compatibility.patch
# ocamlgraph 2.1.0 adds a blank line to the end of its output, breaking tests
Patch:          0005-OCamlgraph-2.1.0-adds-a-newline.patch
# A bugfix in ocaml-re 1.13.3 broke dose3
Patch:          0006-Re-1.13.3-changes.patch

BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-base64-devel >= 3.4.0-1
BuildRequires:  ocaml-camlbz2-devel
BuildRequires:  ocaml-camlp-streams-devel
BuildRequires:  ocaml-camlzip-devel
BuildRequires:  ocaml-cudf-devel
BuildRequires:  ocaml-extlib-devel
BuildRequires:  ocaml-ocamlgraph-devel
BuildRequires:  ocaml-ounit-devel
BuildRequires:  ocaml-parmap-devel
BuildRequires:  ocaml-re-devel

# Test dependencies
BuildRequires:  dpkg
BuildRequires:  %{py3_dist pyyaml}

%description
Dose3 is a framework made of several OCaml libraries for managing
distribution packages and their dependencies.

Though not tied to any particular distribution, dose3 constitutes a pool of
libraries which enable analyzing packages coming from various distributions.

Besides basic functionalities for querying and setting package properties,
dose3 also implements algorithms for solving more complex problems
(monitoring package evolutions, correct and complete dependency resolution,
repository-wide uninstallability checks).

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-base64-devel%{?_isa}
Requires:       ocaml-camlbz2-devel%{?_isa}
Requires:       ocaml-camlzip-devel%{?_isa}
Requires:       ocaml-cudf-devel%{?_isa}
Requires:       ocaml-extlib-devel%{?_isa}
Requires:       ocaml-ocamlgraph-devel%{?_isa}
Requires:       ocaml-re-devel%{?_isa}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

# Since these are applications, I think the correct name is "dose3-tools"
# and not "ocaml-dose3-tools", but I'm happy to change it if necessary.

%package -n dose3-tools
Summary:        Tools suite from the dose3 framework

%description -n dose3-tools
Dose3 is a framework made of several OCaml libraries for managing
distribution packages and their dependencies.

This package contains the tools shipped with the dose3 framework
for manipulating packages of various formats.

%prep
%autosetup -p1 -n dose3-%{version}

# Do not run linkcheck; the koji builders have no network access
sed -i 's/html linkcheck/html/' doc/rtd/Makefile

%build
%dune_build

%install
%dune_install

%check
%dune_check

%files -f .ofiles
%license COPYING
%doc CHANGES CREDITS README.architecture

%files devel -f .ofiles-devel
%license COPYING

%files -n dose3-tools
%license COPYING
%doc doc/apt-cudf/
%{_bindir}/apt-cudf
%{_bindir}/dose-builddebcheck
%{_bindir}/dose-ceve
%{_bindir}/dose-challenged
%{_bindir}/dose-deb-coinstall
%{_bindir}/dose-distcheck
%{_bindir}/dose-outdated



%changelog
* Sat Apr 05 2025 pterjan <pterjan> 7.0.0-5.mga10
+ Revision: 2173857
- Mostly sync with Fedora (we don't have pandoc so don't build the docs)

* Sat May 21 2022 pterjan <pterjan> 7.0.0-4.20200502git.2.mga9
+ Revision: 1859660
- Build with --release to make deprecation warning non fatal
- Rebuild for OCaml 4.14

* Sat Oct 16 2021 tv <tv> 7.0.0-4.20200502git.1.mga9
+ Revision: 1751691
- Version 7.0.0

* Thu Mar 25 2021 tv <tv> 5.0.1-4.20200502git.1.mga9
+ Revision: 1710019
- OCaml 4.12.0 build
- New snapshot
- Depend on ocaml-base64 for Base64 (instead of ocaml-extlib which removed it).

* Sun Jan 10 2021 pterjan <pterjan> 5.0.1-4.20180821git.11.mga8
+ Revision: 1670868
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 5.0.1-4.20180821git.10.mga8
+ Revision: 1551743
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 5.0.1-4.20180821git.9.mga8
+ Revision: 1545762
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 5.0.1-4.20180821git.8.mga8
+ Revision: 1485236
- rebuild for ocaml-re

* Wed Jan 29 2020 tv <tv> 5.0.1-4.20180821git.7.mga8
+ Revision: 1485036
- BR ocaml-seq-devel
- fix requires ending in description since 2013... :-(
- BR ocaml-ocamlbuild thus fixing build
- rebuild for ocaml-4.10
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 16 2019 tv <tv> 5.0.1-4.20180821git.6.mga8
+ Revision: 1441885
- rebuild for rpm-4.15

* Sat Mar 16 2019 daviddavid <daviddavid> 5.0.1-4.20180821git.5.mga7
+ Revision: 1377876
- rebuild for new ocaml-curl 0.8.2

* Thu Oct 25 2018 daviddavid <daviddavid> 5.0.1-4.20180821git.4.mga7
+ Revision: 1325213
- rebuild for new ocaml 4.07.1

* Tue Oct 02 2018 daviddavid <daviddavid> 5.0.1-4.20180821git.3.mga7
+ Revision: 1315956
- rebuild against current ocaml stack

* Sun Sep 23 2018 umeabot <umeabot> 5.0.1-4.20180821git.2.mga7
+ Revision: 1299861
- Mageia 7 Mass Rebuild

* Wed Aug 22 2018 daviddavid <daviddavid> 5.0.1-4.20180821git.1.mga7
+ Revision: 1253359
- update to newer SCM (git) checkout
- modify Makefile in prep section in order to install cmx files
- add debian patch to port it to ocaml-re >= 1.7.2

* Fri Jul 13 2018 daviddavid <daviddavid> 5.0.1-3.mga7
+ Revision: 1243400
- rebuild for new ocaml-extlib 1.7.5

* Sat Mar 24 2018 daviddavid <daviddavid> 5.0.1-2.mga7
+ Revision: 1211861
- rebuild for new ocaml-extlib 1.7.4

* Wed Jan 31 2018 tv <tv> 5.0.1-1.mga7
+ Revision: 1198271
- new release
- fix build
- disable bz2 binding (broken build)
- rebuild for new ocaml

* Fri Oct 06 2017 daviddavid <daviddavid> 4.2-6.mga7
+ Revision: 1169316
- rebuild for new ocaml-cudf 0.9

* Sat Sep 02 2017 daviddavid <daviddavid> 4.2-5.mga7
+ Revision: 1150641
- fix compilation flags thus fixing empty debugsourcefiles.list
+ tv <tv>
- rebuild for new rpm

* Tue Sep 27 2016 pterjan <pterjan> 4.2-4.mga6
+ Revision: 1057035
- Rebuild for changed signature in ocamlgraph

* Mon Sep 26 2016 pterjan <pterjan> 4.2-3.mga6
+ Revision: 1056325
- Rebuild for fix in ocaml

* Tue Feb 23 2016 pterjan <pterjan> 4.2-2.mga6
+ Revision: 977426
- Rebuild for new ocaml-re

* Mon Feb 08 2016 pterjan <pterjan> 4.2-1.mga6
+ Revision: 950714
- Fix file list
- Fix BuildRequires
- Really update to 4.2
- Update to 4.2

* Sun Sep 06 2015 tv <tv> 3.1.3-7.mga6
+ Revision: 873299
- rebuild with new rpm

* Wed Oct 15 2014 umeabot <umeabot> 3.1.3-6.mga5
+ Revision: 747103
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 tv <tv> 3.1.3-5.mga5
+ Revision: 737463
- patch 3 :fix build with rpm-4.12
- use %%autopatch
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.1.3-4.mga4
+ Revision: 526533
- Mageia 4 Mass Rebuild

* Tue Jun 04 2013 malo <malo> 3.1.3-3.mga4
+ Revision: 437230
- add patch to fix manpage generation

* Sat Jan 12 2013 umeabot <umeabot> 3.1.3-2.mga3
+ Revision: 361288
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 malo <malo> 3.1.3-1.mga3
+ Revision: 338248
- new version 3.1.3

* Thu Jan 03 2013 malo <malo> 3.0.2-6.mga3
+ Revision: 338230
- add patch to fix build due to wrong ocamlbuild for-pack directive
+ tv <tv>
- rebuild for new rpm
+ blue_prawn <blue_prawn>
- patch to use extlib-1.5.3
- new rpm group for ocaml
- new rpm group for ocaml
+ fwang <fwang>
- rebuild for new pcre

* Fri Sep 14 2012 malo <malo> 3.0.2-2.mga3
+ Revision: 293883
- fix dangling links (mga#7448)

* Sun Sep 02 2012 malo <malo> 3.0.2-1.mga3
+ Revision: 287316
- new version 3.0.2
- add missing requires for the devel package

* Sat Aug 04 2012 malo <malo> 2.9.10-5.mga3
+ Revision: 278501
- fix requires and buildrequires

* Sun Jun 10 2012 tv <tv> 2.9.10-4.mga3
+ Revision: 259382
- rebuild for new rpm-4.10.0

* Sat Feb 18 2012 malo <malo> 2.9.10-3.mga2
+ Revision: 210169
- renaming requires to ocaml-cudf

* Fri Feb 17 2012 malo <malo> 2.9.10-2.mga2
+ Revision: 210100
- missing requires

* Tue Feb 07 2012 malo <malo> 2.9.10-1.mga2
+ Revision: 205652
- new version 2.9.10
- spec clean-up
- updated file install and list
- new version 2.9.9

* Thu Oct 27 2011 malo <malo> 2.9.8-1.mga2
+ Revision: 158716
- Missing BuildRequires
- new version 2.9.8
- spec rewrite

* Tue Apr 12 2011 ennael <ennael> 2.9.2-2.2457.2.mga1
+ Revision: 83709
- remove deps on dose2

* Tue Apr 12 2011 ennael <ennael> 2.9.2-2.2457.1.mga1
+ Revision: 83661
- fix release tag
- remove rpm5 patch
- clean mdv macros
- imported package ocaml-dose3

